import 'dart:io';

import 'package:spit/spit.dart';
import 'package:path/path.dart' as path;
import 'package:args/args.dart';

abstract class Args {
  static const name = 'name';
  static const author = 'author';
}

Future<void> main(List<String> arguments) async {
  final parser = ArgParser()
    ..addOption(Args.name, abbr: 'n')
    ..addOption(Args.author, abbr: 'a');

  final argResults = parser.parse(arguments);

  final pages = Directory('pages');

  if (!pages.existsSync()) {
    throw Exception('No directory "pages" in current directory');
  }

  final currentName = path.basename(Directory.current.path);

  final documentation =
      await Documentation.load(argResults[Args.name] ?? currentName, pages);
  final file = File('index.html');
  await file.writeAsString(documentation.render());
}
